@@ -1,25 +1,25 @@
 print.lgarch <-
 function(x, arma.version=FALSE, ...)
 {
-  vcovmat <- vcov(x, arma.version=arma.version,
+  pars <- coef.lgarch(x, arma=arma.version)
+  vcovmat <- vcov.lgarch(x, arma.version=arma.version,
     full.matrix=TRUE)
   if(is.null(vcovmat)){
-    vcovmat <- matrix(NA, length(x$par), length(x$par))
-  }
-  if(arma.version){
-    out1 <- rbind(x$par.arma, sqrt(diag(vcovmat)))
-  }else{
-    out1 <- rbind(x$par, sqrt(diag(vcovmat)))
+    vcovmat <- matrix(NA, length(pars), length(pars))
+    colnames(vcovmat) <- names(pars)
+    rownames(vcovmat) <- names(pars)
   }
+  out1 <- rbind(pars, sqrt(diag(vcovmat)))
   rownames(out1) <- c("Estimate:", "Std. Error:")
   out2 <- as.data.frame(matrix(NA,4,1))
   out2[1,1] <- as.character(round(logLik.lgarch(x, arma=FALSE), digits=3))
-  out2[2,1] <- as.character(round(x$objective.arma, digits=3))
-  out2[3,1] <- as.character(round(x$aux$ynonzeron, digits=0))
-  out2[4,1] <- as.character(round(x$aux$yzeron, digits=0))
+  out2[2,1] <- as.character(round(logLik.lgarch(x, arma=TRUE), digits=3))
+  out2[3,1] <- as.character(round(rss.lgarch(x), digits=3))
+  out2[4,1] <- as.character(round(x$aux$ynonzeron, digits=0))
+  out2[5,1] <- as.character(round(x$aux$yzeron, digits=0))
   rownames(out2) <-   c("Log-likelihood (log-garch):",
-    "Log-likelihood (arma):", "No. of non-zeros:",
-    "No. of zeros:")
+    "Log-likelihood (arma):", "Sum Squared Resids. (arma):",
+    "No. of non-zeros:", "No. of zeros:")
   colnames(out2) <- ""
   cat("\n")
   cat("Date:", x$date, "\n")
